registry_management.ghcr.clean_temporary_artifacts()

registry_management.ghcr.clean_temporary_artifacts()

Cleans up temporary caches and images that are not tagged or are older than a given timedelta.

Usage

registry_management.ghcr.clean_temporary_artifacts(
    ghcr_registry, remove_untagged=True, remove_older_than=None, dry_run=False
)
Back to top