config.ImageVersionOS
config.ImageVersionOS
Model representing a supported operating system for an image version.
Usage
config.ImageVersionOS()Methods
| Name | Description |
|---|---|
| __eq__() | Equality check for ImageVersionOS based on name. |
| populate_build_os() | Populates the build_os field based on the name field. If the OS cannot be determined, it defaults to unknown. |
| serialize_platforms() | Serialize the platforms field to a list of strings for YAML output. |
__eq__()
Equality check for ImageVersionOS based on name.
Usage
__eq__(other)Parameters
other- The other object to compare against.
populate_build_os()
Populates the build_os field based on the name field. If the OS cannot be determined, it defaults to unknown.
Usage
populate_build_os(value, info)serialize_platforms()
Serialize the platforms field to a list of strings for YAML output.
Usage
serialize_platforms(platforms)